pub struct DerivData<C: DklsCurve> {
pub depth: u8,
pub child_number: u32,
pub parent_fingerprint: Fingerprint,
pub poly_point: C::Scalar,
pub pk: C::AffinePoint,
pub chain_code: ChainCode,
}Expand description
Contains all the data needed for derivation.
The values that are really needed are only poly_point,
pk and chain_code, but we also include the other ones
if someone wants to retrieve the full extended public key
as in BIP-32. The only field missing is the one for the
network, but it can be easily inferred from context.
Fields
depth: u8Counts after how many derivations this key is obtained from the master node.
child_number: u32Index used to obtain this key from its parent.
parent_fingerprint: FingerprintIdentifier of the parent key.
poly_point: C::ScalarBehaves as the secret key share.
pk: C::AffinePointPublic key.
chain_code: ChainCodeExtra entropy given by BIP-32.
Implementations
Sourceimpl<C: DklsCurve> DerivData<C>
impl<C: DklsCurve> DerivData<C>
Sourcepub fn child_tweak(
&self,
child_number: u32,
) -> Result<(C::Scalar, ChainCode, Fingerprint), ErrorDeriv>
pub fn child_tweak( &self, child_number: u32, ) -> Result<(C::Scalar, ChainCode, Fingerprint), ErrorDeriv>
Computes the “tweak” needed to derive a secret key. In the process, it also produces the chain code and the parent fingerprint.
This is an adaptation of ckd_pub_tweak from the repository:
https://github.com/rust-bitcoin/rust-bitcoin/blob/master/bitcoin/src/bip32.rs.
Errors
Will return Err if the HMAC result is too big (very unlikely).
Sourcepub fn derive_child(
&self,
child_number: u32,
) -> Result<DerivData<C>, ErrorDeriv>
pub fn derive_child( &self, child_number: u32, ) -> Result<DerivData<C>, ErrorDeriv>
Derives an instance of DerivData given a child number.
Errors
Will return Err if the depth is already at the maximum value,
if the child number is invalid or if child_tweak fails.
It will also fail if the new public key is invalid (very unlikely).
Sourcepub fn derive_from_path(&self, path: &str) -> Result<DerivData<C>, ErrorDeriv>
pub fn derive_from_path(&self, path: &str) -> Result<DerivData<C>, ErrorDeriv>
Derives an instance of DerivData following a path
on the “key tree”.
See https://github.com/bitcoin/bips/blob/master/bip-0032.mediawiki for the description of a possible path (and don’t forget that hardened derivations are not implemented).
Errors
Will return Err if the path is invalid or if derive_child fails.