pub struct PublicKeyPackage<C: DklsCurve> { /* private fields */ }Expand description
Aggregates the group public key, per-participant verification shares, and threshold parameters produced by DKG or re-key.
Implementations
Sourceimpl<C: DklsCurve> PublicKeyPackage<C>
Implementations related to BIP-32 derivation for PublicKeyPackage.
impl<C: DklsCurve> PublicKeyPackage<C>
Implementations related to BIP-32 derivation for PublicKeyPackage.
Sourcepub fn derive_child(
&self,
chain_code: &ChainCode,
child_number: u32,
) -> Result<PublicKeyPackage<C>, ErrorDeriv>
pub fn derive_child( &self, chain_code: &ChainCode, child_number: u32, ) -> Result<PublicKeyPackage<C>, ErrorDeriv>
Derives a child PublicKeyPackage given a chain code and child number.
Errors
Will return Err if the child number is invalid or the HMAC
result is out of range (very unlikely).
Sourceimpl<C: DklsCurve> PublicKeyPackage<C>
impl<C: DklsCurve> PublicKeyPackage<C>
pub fn new( verifying_key: C::AffinePoint, verifying_shares: BTreeMap<PartyIndex, C::AffinePoint>, parameters: Parameters, ) -> Self
pub fn verifying_key(&self) -> &C::AffinePoint
pub fn threshold(&self) -> u8