pub struct EncProof<C: DklsCurve> {
pub proof0: CPProof<C>,
pub proof1: CPProof<C>,
pub commitments0: RandomCommitments<C>,
pub commitments1: RandomCommitments<C>,
pub challenge0: C::Scalar,
pub challenge1: C::Scalar,
}Expand description
Encryption proof used during the Endemic OT protocol of Zhou et al.
See page 17 of https://eprint.iacr.org/2022/1525.pdf.
Fields
proof0: CPProof<C>EncProof is a proof that proof0 or proof1 really proves what it says.
proof1: CPProof<C>commitments0: RandomCommitments<C>commitments1: RandomCommitments<C>challenge0: C::Scalarchallenge1: C::ScalarImplementations
Sourceimpl<C: DklsCurve> EncProof<C>
impl<C: DklsCurve> EncProof<C>
Sourcepub fn prove(
session_id: &[u8],
base_h: &C::AffinePoint,
scalar: &C::Scalar,
bit: bool,
) -> EncProof<C>
pub fn prove( session_id: &[u8], base_h: &C::AffinePoint, scalar: &C::Scalar, bit: bool, ) -> EncProof<C>
Computes a proof for the witness scalar.
The variable bit indicates which one of the proofs is really
proved by scalar. The other one is simulated.
Sourcepub fn verify(&self, session_id: &[u8]) -> bool
pub fn verify(&self, session_id: &[u8]) -> bool
Verification of an encryption proof.
Note that the data to be verified is in proof.
Sourcepub fn get_u_and_v(&self) -> (C::AffinePoint, C::AffinePoint)
pub fn get_u_and_v(&self) -> (C::AffinePoint, C::AffinePoint)
Extracts u and v from an instance of EncProof.
Be careful: the notation for u and v here is the
same as the one used in the paper by Zhou et al. at page 17.
Unfortunately, u and v appear in the other order in
their description of the Chaum-Pedersen protocol.
Hence, u and v here are not the same as point_u
and point_v in CPProof.